<?php // $Id: block_backadel.php,v 1.2 2009/04/08 17:31:10 rrusso Exp $

/**
 * @author Adam Zapletal
 * @Louisana State University
 */

require_once('lib.php');
require_once($CFG->dirroot . '/backup/lib.php');
require_once($CFG->dirroot . '/backup/backuplib.php');

class block_backadel extends block_list {

    function init() {
        $this->title = get_string('blockname', 'block_backadel');
        $this->version = 2008102200;
        $this->cron = 3600;
    }

    /**
     * Limits where the block can be added.
     **/
    function applicable_formats() {
        return array('site' => true, 'my' => false, 'course' => false);
    }

    function get_content() {

        global $USER;

        // Don't return any content if the user isn't a site administrator
        // Otherwise return then previously generated content if available
        if (!is_siteadmin($USER->id)) {
            return null;
        } else if ($this->content !== null) {
            return $this->content;
        }

        global $CFG;

        $this->content = new stdClass;
        $this->content->footer = '';

/* taken out because this inserts icons into their own div and this is unfixable in the IE flavors. Instead I moved the icons into the items array
        $this->content->icons = array(
            'index'  => '<img src="' . $CFG->pixpath . '/i/backup.gif" alt="\" />',
            'delete' => '<img src="' . $CFG->pixpath . '/i/cross_red_big.gif" alt="\" />',
            'failed' => '<img src="' . $CFG->pixpath . '/i/sadface.gif" alt="\" />',
            );
*/
        $this->content->icons = array();

        // Count the number of backup attempts that were successful and failed
        $num_pending = count_records_select('block_backadel_statuses', "status='SUCCESS'");
        $num_failed = count_records_select('block_backadel_statuses', "status='FAIL'");

        $this->content->items = array(
            'index'  => '<img src="' . $CFG->pixpath . '/i/backup.gif" alt="\" /> ' . $this->build_link('index.php', 'block_backup'),
            'delete' => '<img src="' . $CFG->pixpath . '/i/cross_red_big.gif" alt="\" /> ' . $this->build_link('delete.php', 'block_delete') . ' (' . $num_pending . ')',
            'failed' => '<img src="' . $CFG->pixpath . '/i/sadface.gif" alt="\" /> ' . $this->build_link('failed.php', 'block_failed') . ' (' . $num_failed . ')',
            'upload' => '<img src="' . $CFG->pixpath . '/f/text.gif" alt="\" /> ' . $this->build_link('bulk_delete.php', 'block_bulk_delete'),
        );

        return $this->content;
    }

    /**
     * Helper method to build links
     */
    function build_link($page, $string) {
        global $CFG;
        return '<a href="' . $CFG->wwwroot . '/blocks/backadel/' . $page . '">' . get_string($string, 'block_backadel') . '</a>';
    }

    /**
     * Hourly cron job that iterates over courses flagged to be backed up and proceeds to back them up.
     */
    function cron() {

        global $CFG;

        // Check for backups waiting to be processed; exit if there are none available
        $backups = get_records('block_backadel_statuses', 'status', 'BACKUP');

        if (!$backups) {
            return;
        }

        define('BACKUP_SILENTLY', 1);

        $destination = $CFG->dataroot . '/' . get_config('block/backadel', 'path');
        $error_log = '';

        foreach ($backups as $b) {

            $error = '';

            // Determine name of the backup based upon course's shortname and the configured suffix
            $shortname = get_field('course', 'shortname', 'id', $b->coursesid);
            $name = $shortname . generate_suffix($b->coursesid); 

            echo "\n" . get_string('backing_up', 'block_backadel') . ' ' . $shortname . "\n";

            // Backup course and update the attempt's status based on the outcome
            backup_execute(prepare_backup_prefs($b->coursesid, $name, $destination), $error);
            $b->status = (!$error) ? 'SUCCESS' : 'FAIL';
            update_record('block_backadel_statuses', $b);

            $error_log .= $error;
        }

        // Notify administrators of errors that occurred during the backup process
        backadel_email_admins($error_log);
    }
}

?>
