<?php // $Id: config.php,v 1.2 2009/04/08 17:31:45 rrusso Exp $

/**
 * @author Adam Zapletal
 * @Louisana State University
 */

require_once('../../config.php');
require_once('lib.php');

require_login();

if (!is_siteadmin($USER->id)) {
    error(get_string('need_permission', 'block_backadel'));
}

$error = '';

$path = '';
$pattern = '';
$roles = array();
$changes = False;

// Process post data if it exists
if ($raw_data = data_submitted()) {
    $changes = True;
    $clean_data = array();

    // Clean post data
    foreach ($raw_data as $key => $value) {
        $clean_data[$key] = clean_param($value, PARAM_CLEAN);
    }

    $path    = $clean_data['path'];
    $pattern = $clean_data['pattern'];
    $roles   = $clean_data['roles'];

    if ($path) {

        $full_path = $CFG->dataroot . '/' . $path;

        if (is_writeable($full_path) && is_dir($full_path)) {
            set_config('path', $path, 'block/backadel');

            $path_changes_saved = True;
        } else {
            $error .= get_string('path_error', 'block_backadel');
        }
    }

    if ($pattern) {
        set_config('pattern', $pattern, 'block/backadel');

        $other_changes_saved = True;
    }

    if ($roles) {
        set_config('roles', implode(',', $roles), 'block/backadel');

        $other_changes_saved = True;
    }
}

// Get current values from the database
if (!$path) {
    $path = get_config('block/backadel', 'path');
}

$pattern = get_config('block/backadel', 'pattern');
$roles = explode(',', get_config('block/backadel', 'roles'));

// Setup and print navbar and header
$header = get_string('config_header', 'block_backadel');
$block = array('name' => get_string('blockname', 'block_backadel'), 
               'type' => 'title');
$page = array('name' => $header);
$nav = array($block, $page);

print_header_simple($header, '', build_navigation($nav));
print_heading_with_help($header, 'build_query', 'block_backadel');

// Get Moodle's roles that admin can choose from
$moodle_roles = get_records_sql('SELECT name, id FROM mdl_role WHERE shortname NOT IN' . 
                         ' (\'student\', \'admin\', \'guest\', \'user\') ORDER BY name ASC');

// Conditionally print "Changes Saved" message
if (!$error && $changes) {
    echo '<div class = "changes_saved">' . get_string('changes_saved', 'block_backadel') . '</div>';
}

// Print main table
// If the name of this script ever changes, change this line
echo '  <form action = "config.php" method = "post">
        <table>
            <tr>
                <td class="leftcolumn">' . get_string('config_path', 'block_backadel') . ':</td>
                <td class="rightcolumn"> ';
                
if ($error) {
    echo '<div class = "error">' . $error . '</div>';
}                
                
echo $CFG->dataroot . '/' .
                '   <input type = "text" name = "path" value = "' . $path . '"/></td>
            </tr>
            <tr>
                <td class="leftcolumn">' . get_string('config_pattern', 'block_backadel') . ':</td>
                <td class="rightcolumn">shortname_ <select name = "pattern">';
                    
// Print pattern select with current value already selected
foreach (array('username', 'idnumber', 'fullname') as $v) {
    if ($v == $pattern) {
        echo '      <option selected = "selected">' . $v . '</option>';
    } else {
        echo '      <option>' . $v . '</option>';
    }
}

echo '             </select>
                </td>
            </tr>
            <tr>
                <td class="leftcolumn">' . get_string('config_roles', 'block_backadel') . ':</td>
                <td class="rightcolumn"><select name = "roles[]" multiple = "multiple">';

// Print roles select with current values already selected
foreach ($moodle_roles as $r) {
    if (in_array($r->id, $roles)) {
        echo '           <option value = "' . $r->id . '" selected = "selected">' . $r->name . '</option>';
    } else {
        echo '           <option value = "' . $r->id . '">' . $r->name . '</option>';
    }
}

$sched_link  = '<a href = "' . $CFG->wwwroot . '/admin/settings.php?section=backups" ';
$sched_link .= '>' . get_string('here', 'block_backadel');
$sched_link .= '</a>';

echo '          </select></td>
            </tr>
            <tr>
                <td colspan = "2">' . get_string('backup_config', 'block_backadel') . $sched_link . '</td>
            </tr>
            <tr>
                <td colspan = "2"><input class="saved_query_button" type = "submit" value = "' . 
                get_string('save_config', 'block_backadel') . '"/></td>
            </tr>
        </table>
        </form>';

        print_footer();
?>
