/**
 * @author Adam Zapletal
 * @Louisana State University
 */

// Counts how many constraint divs are on the page
// This is used to increment the id of the next constraint
function count_constraints() {
    var divs = document.getElementsByTagName('div');
    var count = 0;

    for(var i = 0; i < divs.length; i++) {
        if (divs[i].className == 'constraint') {
            count++;
        }
    }

    return count;
}

// Returns an array of all search_term divs for a given constraint number
function get_search_terms(constraint_num) {
    var arr = new Array();

    var inputs = document.getElementsByTagName('div');

    for(var i = 0; i < inputs.length; i++) {
        if(inputs[i].id.search('c' + constraint_num + '_search_term_') > -1) {
            arr.push(inputs[i]);
        }
    }

    return arr;
}

// Adds a new constraint with a given id to the bottom of the form
function add_constraint(num) {
    var elem = document.createElement('div');
    elem.id = 'c' + num + '_constraint';
    elem.className = 'constraint';
    
    var s = '<select name = "c' + num + '_criteria"><option>Shortname</option><option>Fullname</option>';
    s += '<option>Course Id #</option><option>Category</option>';
    s += '</select> <select name = "c' + num + '_operator"><option>is</option>';
    s += '<option>is not</option><option>contains</option>';
    s += '<option>does not contain</option></select> ';
    s += '<span id = "c' + num + '_search_term_0">';
    s += '<input name = "c' + num + '_search_term_0" type = "text"/> ';
    s += '<input id = "c' + num + '_st_num" value = "1" type = "hidden"/>';
    s += '<img src = "add.png" onclick = "add_search_term(' + num + ')" /></span>';

    elem.innerHTML = s;
    gc = document.getElementById('group_constraints');
    gc.appendChild(elem);
}

// Adds a new search term to the constraint with a given id
function add_search_term(num) {
    // The following block figures out which id should be given to the div
    // This is complicated because the user is able to add and remove out of order
    var c = document.getElementById('c' + num + '_constraint');
    var st_num = document.getElementById('c' + num + '_st_num').value;
    var elem = document.createElement('div');
    elem.id = 'c' + num + '_search_term_' + st_num;
    elem.className = 'search_term';

    var s = '<div class = "search_term_or">OR</div>';
    s += '<div class = "search_term_input">';
    s += '<input name = "c' + num + '_search_term_' + st_num + '" type = "text"> ';
    s += '<img src = "delete.png" ';
    s += 'onclick = "remove_search_term(' + num + ', ' + st_num + ')"></div></div></div>';

    elem.innerHTML = s;
    c.appendChild(elem);
    st_num_elem = document.getElementById('c' + num + '_st_num');
    st_num_elem.value = parseInt(st_num_elem.value) + 1
}

// A general helper function to wrap deleting an element from the page given
// a parent element's id  and a child element's id
function remove_elem(parent, child) {
    var parentElem = document.getElementById(parent);
    var childElem = document.getElementById(child);

    parentElem.removeChild(childElem);
}

// Removes the last constraint on the page
function remove_constraint() {
    var count = count_constraints();
    if(count > 1) {
        remove_elem('group_constraints', 'c' + (count - 1) + '_constraint');
    }
}

// Removes the search term from the page with a given constraint number and 
// search term number
function remove_search_term(cons, term) {
    var parent = 'c' + cons + '_constraint';
    var child = 'c' + cons + '_search_term_' + term;

    parentElem = document.getElementById(parent);
    
    search_terms = get_search_terms(cons);

    var r = new RegExp('_' + term + '$');

    for(var i = 0; i < search_terms.length; i++) {
        if (r.test(search_terms[i].id)) { 
            parentElem.removeChild(search_terms[i]);
        }
    }
}

// Ensures that the user has given the query a name and at least one search term
function validate_results() {
    if (document.getElementsByName('name')[0].value == '') {
        var s = 'Please select a name for this query<br />';
        document.getElementById('results_error').innerHTML = s;

        return false;
    }

    if (document.getElementsByName('c0_search_term_0')[0].value == '') {
        var s = 'Please select at least one search term for this constraint<br />';
        document.getElementById('results_error').innerHTML = s;

        return false;
    }

    return true;
}

// Checks that a radio button is checked in the lower form of index.php
function validate_backup() {
    var elems = document.getElementsByTagName('input');

    for (var i = 0; i < elems.length; i++) {
        if (elems[i].type == 'radio' && elems[i].checked) {
            return true;
        }
    }
    
    var s = 'Please select a saved search<br />';
    document.getElementById('backup_error').innerHTML = s;

    return false;
}
