<?php // $Id: lib.php,v 1.2 2009/04/08 17:32:41 rrusso Exp $

/**
 * @author Adam Zapletal
 * @Louisana State University
 */

//require_once('../../config.php');
require_once($CFG->dirroot . '/backup/backup_scheduled.php');

// Creates a sql query from a query object and 1..n constraint objects
// This is called from results.php and backup.php
function build_sql_from_search($query, $constraints) {
    global $CFG;

    // Map criteria options to sql fields
    $criteria_names = array('Shortname'     => 'co.shortname', 
                            'Fullname'      => 'co.fullname',
                            'Course Id #'   => 'co.idnumber',
                            'Category'      => 'cat.name');

    // Map english operators to sql operators 
    $operators = array('is'               => 'IN',
                       'is not'           => 'NOT IN',
                       'contains'         => 'LIKE',
                       'does not contain' => 'NOT LIKE');

    // Switch ANY/ALL to OR/AND
    $conjunction = $query->type == 'ALL' ? 'AND' : 'OR';
    
    // Boilerplate select part of the query
    $sql  = 'SELECT co.id, co.fullname, co.shortname, co.idnumber, cat.name ';
    $sql .= "as category FROM {$CFG->prefix}course co, {$CFG->prefix}course_categories cat WHERE ";
    $sql .= 'co.category = cat.id AND (';

    // Transform each constraint object into a part of the sql query
    foreach ($constraints as $c) {
        $sql .= '(';

        // Sql syntax for (NOT) LIKE
        if ($c->operator == 'contains' || $c->operator == 'does not contain') {
            foreach (explode('|', $c->search_terms) as $s) {
                $sql .= $criteria_names[$c->criteria] . ' ' . $operators[$c->operator];
                $sql .= ' \'%' . $s . '%\' OR ';
            }

            $sql = substr($sql, 0, -4);

        // Sql syntax for (NOT) IN 
        } else {
            $sql .= $criteria_names[$c->criteria] . ' ' . $operators[$c->operator] . '(';

            foreach (explode('|', $c->search_terms) as $s) {
                $sql .= '\'' . $s . '\', ';
            }

            $sql = substr($sql, 0, -2) . ')';
        }

        $sql .= ') ' . $conjunction . ' ';
    }

    // Trim excess and return sql statement
    return substr($sql, 0, -(strlen($conjunction) + 2)) . ');';
}

// Wrapper so build_sql_from_search is callable with a queryid
function build_sql_from_queryid($queryid) {
    if (!$query = get_record('block_backadel_queries', 'id', $queryid)) {
        // This should never be reached due to js validation
        echo 'Error: Could not find query';
        die();
    }

    if (!$constraints = get_records('block_backadel_constraints', 'queriesid', $queryid)) {
        // This should never be reached due to js validation
        echo 'Error: Could not find constraints';
        die();
    }

    return build_sql_from_search($query, $constraints);
}

// This function prepares a preference object for the backup_execute function.
// This block uses the scheduled backups prefs grab options.
function prepare_backup_prefs($id, $name, $destination) {
    global $CFG;

    $CFG->libdir = $CFG->dirroot . '/lib';

    $course = get_record('course', 'id', $id);
    $preferences = schedule_backup_course_configure($course);
    $preferences->backup_name = $name . '_' . $preferences->backup_unique_code . '.zip';
    $preferences->backup_destination = $destination;
    
    return $preferences;
}

// Generates the last bit of the backup .zip's filename based on the
// pattern and roles that the admin chose in config.
function generate_suffix($courseid) {

    $suffix = '';
    $field = get_config('block/backadel', 'pattern');
    $roleids = explode(',', get_config('block/backadel', 'roles'));    
    $context = get_context_instance(CONTEXT_COURSE, $courseid);

    if ($field != 'fullname') {
        foreach ($roleids as $r) {
            if ($users = get_role_users($r, $context, false, 'u.' . $field)) {
                foreach ($users as $k => $v) {
                    $suffix .= '_' . $k;
                }
            }
        }
    } else {
        foreach ($roleids as $r) {
            if ($users = get_role_users($r, $context, false, 'u.firstname, u.lastname')) {
                foreach ($users as $k => $v) {
                    $suffix .= '_' . $v->firstname . $v->lastname;
                }
            }
        }
    }

    return $suffix;
}

// Emails admins about backup completions.
function backadel_email_admins($errors) {
    global $CFG;
    
    $sql = "SELECT u.*
            FROM {$CFG->prefix}user u,
                 {$CFG->prefix}role_assignments ra
            WHERE ra.roleid = 1
            AND ra.userid = u.id";

    $admin_users = get_records_sql($sql);
    $subject = get_string('email_subject', 'block_backadel');
    $from = get_string('email_from', 'block_backadel');
    $messagetext  = implode("\n", $errors);
    $messagetext .= get_string('email_body', 'block_backadel', $CFG);

    foreach ($admin_users as $admin) {
        email_to_user($admin, $from, $subject, $messagetext);
    }
}

// Deletes specified course, logs, and sends event
// Much of this code was taken from /course/delete.php
function backadel_delete_course($courseid) {
    $course = get_record('course', 'id', $courseid);

    add_to_log(SITEID, "course", "delete", "view.php?id=$course->id", "$course->fullname (ID $course->id)");
    $ret = delete_course($courseid, false);
    fix_course_sortorder(); //update course count in catagories

    // MDL-9983
    events_trigger('course_deleted', $course);    

    return $ret;
}

// Conditionally echoes the code that changes checkbox state
function check($v) {
    return ($v) ? "checked = \"checked\" " : "";
}

?>
